@@ -1,6 +1,6 @@
 from strange_case.nodes import PageNode
 from strange_case.registry import Registry
-
+from strange_case.support.jinja import fix_path
 
 class JinjaNode(PageNode):
     """
@@ -16,15 +16,9 @@ class JinjaNode(PageNode):
         self.files_written.append(target_path)
 
     def render(self, site=None):
-        source_path = self.source_path
-        # source_path could be an absolute path, in which case jinja2 actually
-        # gets confused.  remove the site_path from source_path so this doesn't
-        # happen.
-        if source_path[0] == '/':
-            source_path = source_path[len(self.config['project_path']):]
-
+        #print "self.source_path is '{}', fixed to '{}'".format(self.source_path, fix_path(self.source_path))
         try:
-            template = Registry.get('jinja_environment').get_template(source_path)
+            template = Registry.get('jinja_environment').get_template(fix_path(self.source_path))
         except UnicodeDecodeError as e:
             e.args += "Could not process '%s' because of unicode error." % self.source_path
             raise
